/*****************************************************************
 * Copyright (c) 2016 Texas Instruments and others
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Paul Gingrich - Initial API and implementation
 *****************************************************************/
var gc = gc || {};
gc.databind = gc.databind || {};

/** 
 * Abstract class that implements IPacketCodec interface.  This abstract
 * implements the default isConnected capabilities, with are true if any
 * data is processed.
 *    
 * @constructor
 * @implements gc.databind.IPacketCodec
 */
gc.databind.AbstractPacketCodec = function()
{
};

/**
 * Encodes data into a packet for sending.  
 *    
 * @param data {Object} - The data object to encode into a packet for sending.  
 * @return {Number[]}  - The encoded raw packet data, as an array of bytes.   
 */
gc.databind.AbstractPacketCodec.prototype.encode = function(data) 
{
    return data;
};

/**
 * Decodes packets into data objects.  One object for each packet of data.  The packet data is not framed,
 * so this method is responsible for decoding partial packets as well as multiple packets.  Partial packets
 * should not be returned, but deferred until the next decode method call with more raw data to process.  As a 
 * result, this method may return 0 or more packets of data on each invocation. 
 *    
 * @param rawData {Number[]} - The raw data received that needs to be decoded from packets into objects.  
 * @param streamingModel {gc.databind.AbstractStreamingDataModel} - The AbstractStreamingDataModel to push packet data objects through.  
 */
gc.databind.AbstractPacketCodec.prototype.decode = function(data, streamingModel)
{
    this._isConnected = true;
    streamingModel.receiveData(data);
};

gc.databind.AbstractPacketCodec._isConnected = false;

/**
 * Tests if the transport is connected.  The connected state should begin as false or unconnected until a 
 * valid packet is received.  Afterwich it should return true or false based on whether valid packets are 
 * being received or not.
 *    
 * @param rawData {Number[]} - The raw data received that needs to be decoded from packets into objects.  
 * @return {Object[]} - Array of decoded data objects, one for each packet received, if any.      
 */
gc.databind.AbstractPacketCodec.prototype.isConnected = function(data) 
{
    return this._isConnected;
};
